---
name: "Bug report \U0001F41B"
about: Create a bug report to help us improve
title: "[BUG] "
labels: "bug \U0001F41B"
assignees: ''

---

# Bug report

## Summary

*Please enter a brief description of your issue*

## Description

*Please describe your issue in detail*

## Steps to reproduce

*Please enumerate the steps to follow in order to reproduce the issue. If possible, please provide a minimal reproducible example.*

1. ...
2. ...

## System configuration

*Please provide information regarding your system configuration*

- Operating system: ...
- Compiler: ...
- Python version: ... *(get it from `python --version)`*
- Eradiate version: ... *(get it from `eradiate show`)*
